%ifarch %{arm} aarch64
%define build_docs     0
%else
%define build_docs     1
%endif

%define rel 1

Name:           qbs
Version:        1.24.0
Release:        %mkrel %{rel}
Summary:        Qt5 Build System
Group:          Development/KDE and Qt
# See LGPL_EXCEPTION.txt
License:        LGPLv2 with exceptions and LGPLv3 with exceptions
URL:            https://wiki.qt.io/qbs
Source0:        https://download.qt.io/official_releases/%{name}/%{version}/%{name}-src-%{version}.tar.gz

BuildRequires:  pkgconfig(Qt5Concurrent)
BuildRequires:  pkgconfig(Qt5Core)
BuildRequires:  pkgconfig(Qt5Gui)
BuildRequires:  pkgconfig(Qt5Help)
BuildRequires:  pkgconfig(Qt5Network)
BuildRequires:  pkgconfig(Qt5Script)
BuildRequires:  pkgconfig(Qt5Test)
BuildRequires:  pkgconfig(Qt5Widgets)
BuildRequires:  pkgconfig(Qt5Xml)

BuildRequires:  libstdc++-static-devel

%description
Qbs is a tool that helps simplify the build process for developing projects
across multiple platforms. Qbs can be used for any software project, regardless
of programming language, toolkit, or libraries used.

Qbs is an all-in-one tool that generates a build graph from a high-level
project description (like qmake or CMake) and additionally undertakes the task
of executing the commands in the low-level build graph (like make).

%files
%doc README.md
%{_bindir}/*
%{_datadir}/qbs/
%{_libdir}/qbs/
%{_libexecdir}/qbs/
%{_mandir}/man1/qbs.1.*

#--------------------------------------------------------------------

%define qbscore_major 1
%define libqbscore %mklibname qbscore %{qbscore_major}

%package -n     %{libqbscore}
Summary:        Qbs Core library
Group:          System/Libraries

%description -n %{libqbscore}
Qbs Core library.

%files -n %{libqbscore}
%{_libdir}/libqbscore.so.%{qbscore_major}{,.*}

#--------------------------------------------------------------------

%define libqbs_d %mklibname %{name} -d

%package -n     %{libqbs_d}
Summary:        Devel files needed to build apps based on %{name}
Group:          Development/KDE and Qt
Requires:       %{libqbscore} = %{version}-%{release}
Provides:       lib%{name}-devel = %{version}
Provides:       %{name}-devel = %{version}

%description -n %{libqbs_d}
Devel files needed to build apps based on %{name}.

%files -n %{libqbs_d}
%{_includedir}/%{name}/
%{_libdir}/*.so
%{_libdir}/*.prl

#------------------------------------------------------------------------------

%if %{build_docs}
%package        doc
Summary:        Documentation for %{name}
Group:          Documentation
License:        GFDL
BuildArch:      noarch
BuildRequires:  qttools5
# This one is required to build QCH-format documentation
# for APIs and tools in this package set
BuildRequires:  qttools5-assistant
Recommends:     qttools5-assistant

%description    doc
HTML documentation for %{name}.

%files doc
%dir %{_docdir}/%{name}
%doc %{_docdir}/%{name}/%{name}.qch
%doc %{_docdir}/%{name}/html/
%endif

#------------------------------------------------------------------------------

%prep
%setup -q -n %{name}-src-%{version}
%autopatch -p1

%build
%qmake_qt5 \
  QBS_INSTALL_PREFIX=%{_prefix} \
  QBS_LIBRARY_DIRNAME=%{_lib} \
  QBS_LIBEXEC_INSTALL_DIR=%{_libexecdir}/%{name} \
  QBS_RELATIVE_LIBEXEC_PATH=../libexec/%{name} \
  CONFIG+=qbs_enable_project_file_updates \
  CONFIG+=qbs_disable_rpath \
  CONFIG+=qbs_enable_unit_tests \
  CONFIG+=nostrip \
  QMAKE_LFLAGS="-Wl,--as-needed" \
  qbs.pro
# LD_LIBRARY_PATH: Because the qbs executable built is itself invoked, and it requires the built qbs libraries
LD_LIBRARY_PATH=%{_lib} %make_build

%if %{build_docs}
%make_build docs
%make_build html_docs
%endif

%install
%make_install INSTALL_ROOT=%{buildroot}

%if %{build_docs}
%make_install install_docs INSTALL_ROOT=%{buildroot}
%endif

# Remove python dmgbuild code, it only works on macOS (#1559529)
rm -rf %{buildroot}%{_datadir}/qbs/python/mac_alias/
rm -rf %{buildroot}%{_datadir}/qbs/python/ds_store/
rm -rf %{buildroot}%{_datadir}/qbs/python/dmgbuild/
rm -rf %{buildroot}%{_datadir}/qbs/python/biplist/
rmdir %{buildroot}%{_datadir}/qbs/python/
rm -f %{buildroot}%{_libexecdir}/qbs/dmgbuild


%changelog
* Tue Dec 27 2022 daviddavid <daviddavid> 1.24.0-1.mga9
+ Revision: 1927226
- New version 1.24.0

* Tue Nov 15 2022 daviddavid <daviddavid> 1.23.2-1.mga9
+ Revision: 1907713
- new version: 1.23.2
+ neoclust <neoclust>
- New version 1.23.1

* Mon Apr 04 2022 umeabot <umeabot> 1.19.0-2.mga9
+ Revision: 1843615
- Mageia 9 Mass Rebuild

* Tue May 18 2021 daviddavid <daviddavid> 1.19.0-1.mga9
+ Revision: 1725307
- new version: 1.19.0

* Mon Dec 28 2020 daviddavid <daviddavid> 1.18.0-1.mga8
+ Revision: 1664424
- new version: 1.18.0

* Thu Dec 17 2020 umeabot <umeabot> 1.17.0-2.mga8
+ Revision: 1659445
- Rebuild for new Qt5

* Fri Sep 11 2020 daviddavid <daviddavid> 1.17.0-1.mga8
+ Revision: 1624639
- new version: 1.17.0

* Fri May 08 2020 daviddavid <daviddavid> 1.16.0-1.mga8
+ Revision: 1581610
- new version: 1.16.0

* Tue Feb 18 2020 daviddavid <daviddavid> 1.15.0-2.mga8
+ Revision: 1539946
- remove python dmgbuild code, it only works on macOS
+ umeabot <umeabot>
- Mageia 8 Mass Rebuild

* Fri Dec 13 2019 daviddavid <daviddavid> 1.15.0-1.mga8
+ Revision: 1466544
- new version: 1.15.0

* Sat Nov 23 2019 daviddavid <daviddavid> 1.14.1-1.mga8
+ Revision: 1462325
- new version: 1.14.1

* Thu Oct 10 2019 daviddavid <daviddavid> 1.14.0-1.mga8
+ Revision: 1451123
- new version: 1.14.0

* Sun Jun 30 2019 daviddavid <daviddavid> 1.13.1-1.mga8
+ Revision: 1416371
- new version: 1.13.1

* Mon Apr 01 2019 umeabot <umeabot> 1.12.2-2.mga7
+ Revision: 1384146
- Qt5 Rebuild

* Mon Dec 17 2018 daviddavid <daviddavid> 1.12.2-1.mga7
+ Revision: 1342180
- new version: 1.12.2

* Tue Sep 25 2018 daviddavid <daviddavid> 1.12.1-1.mga7
+ Revision: 1304937
- new version: 1.12.1

* Sun Sep 23 2018 umeabot <umeabot> 1.12.0-3.mga7
+ Revision: 1300635
- Mageia 7 Mass Rebuild

* Thu Jul 19 2018 daviddavid <daviddavid> 1.12.0-2.mga7
+ Revision: 1244392
- fix missing header on settingsrepresentation.h

* Thu Jul 19 2018 daviddavid <daviddavid> 1.12.0-1.mga7
+ Revision: 1244328
- new version: 1.12.0

* Tue May 08 2018 daviddavid <daviddavid> 1.11.1-1.mga7
+ Revision: 1227598
- new version: 1.11.1
- remove merged upstream patch

* Mon May 07 2018 neoclust <neoclust> 1.11.0-4.mga7
+ Revision: 1226939
- Enhance configure

* Mon May 07 2018 neoclust <neoclust> 1.11.0-3.mga7
+ Revision: 1226934
- Rebuild qbs against latest Qt5

* Thu Mar 29 2018 daviddavid <daviddavid> 1.11.0-2.mga7
+ Revision: 1213367
- add patch to install missing header (projectgeneratormanager.h)

* Wed Mar 28 2018 daviddavid <daviddavid> 1.11.0-1.mga7
+ Revision: 1213169
- new version: 1.11.0
- remove merged upstream patch

* Sun Oct 08 2017 daviddavid <daviddavid> 1.9.1-1.mga7
+ Revision: 1170170
- new version: 1.9.1
- add an HTML doc package
- improve Summary and description

* Fri Mar 11 2016 daviddavid <daviddavid> 1.2.2-5.mga6
+ Revision: 989347
- add patch to fix build against Qt5.5
+ umeabot <umeabot>
- Mageia 6 Mass Rebuild

* Wed Oct 15 2014 umeabot <umeabot> 1.2.2-4.mga5
+ Revision: 742271
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 1.2.2-3.mga5
+ Revision: 688464
- Mageia 5 Mass Rebuild

* Fri Aug 22 2014 neoclust <neoclust> 1.2.2-2.mga5
+ Revision: 666550
- Fix file removal
- imported package qbs

